# pcm
Pychron Configuration Manager

This is a simple "command line interface" aka `cli` for build pychron configuration
files. 

It can also be used to install the pychron source code, build the necessary python environment and install launcher 
scripts


# Installation

```shell
pip install pychron-cm
```

# Usage


```shell

pcm wizard
```
or for help

```shell
pcm --help
```